==> haskell-lens-aeson-1.2.3-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-7HH6euWCV7DEP7hSlSPouO
key:                  lens-aeson-1.2.3-7HH6euWCV7DEP7hSlSPouO
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  973f69cb3d99f640c9ffc0932a9f75d2
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-7HH6euWCV7DEP7hSlSPouO
depends:
    aeson-2.1.2.1-8gRdOgbBkF57DAEniCzHis base-4.17.2.1
    bytestring-0.11.5.3 lens-5.3-6U8rnlrA3UzGhSFoVj5hOc
    scientific-0.3.8.0-3JrZTDh3ZlGFN4TNaQrQZi text-2.0.2
    text-short-0.1.6-G05xAmjvzxF6KbLM99PA0Y
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP
    vector-0.13.2.0-GDtmlcfK9QZ7E5AlTQVnIi

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.2.3-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-2MHR3QpU45z9mFygdRXMUn
key:                  lens-aeson-1.2.3-2MHR3QpU45z9mFygdRXMUn
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  d4b5a8fedf80308a792785d3bdad8707
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-2MHR3QpU45z9mFygdRXMUn
depends:
    aeson-2.1.2.1-HUj8Ou2Jrr19darX8iyQt4 base-4.17.2.1
    bytestring-0.11.5.3 lens-5.3-6U8rnlrA3UzGhSFoVj5hOc
    scientific-0.3.8.0-3JrZTDh3ZlGFN4TNaQrQZi text-2.0.2
    text-short-0.1.6-G05xAmjvzxF6KbLM99PA0Y
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP
    vector-0.13.2.0-GDtmlcfK9QZ7E5AlTQVnIi

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
